@@ -1,7 +1,7 @@
 -- file: HUnitAug.hs
 
 -- Haskell bindings for the Augeas library
--- Copyright (c) 2009-2011, Jude Nagurney
+-- Copyright (c) 2009-2012, Jude Nagurney
 
 -- This library is free software; you can redistribute it and/or modify it 
 -- under the terms of the GNU Lesser General Public License as published by 
@@ -223,7 +223,8 @@ testSetMultiMatch = TestCase ( with_augptr $ \aug_ptr -> do
                               assertEqual "set OK" System.Augeas.error ret_set
 
                               ret_error <- aug_error aug_ptr
-                              assertEqual "testSetMultiMatch error" no_error ret_error
+                              -- assertEqual "testSetMultiMatch error" no_error ret_error
+                              assertEqual "testSetMultiMatch error" err_multi_matches ret_error
 
                              )
 #endif
@@ -537,6 +538,48 @@ testPrint = TestCase ( with_augptr $ \aug_ptr -> do
                      )
 #endif
 
+-- --------------
+-- aug_srun tests
+-- --------------
+#ifdef HAS_AUGEAS_SRUN
+testSrunHelp :: Test
+testSrunHelp = TestCase ( with_augptr $ \aug_ptr -> do                         
+                         
+                         cwd <- getCurrentDirectory
+                         fptr_Output <- openFile (cwd++"/HUnitAug.txt") WriteMode
+                         ret_srun <- aug_srun aug_ptr fptr_Output (Data.ByteString.Char8.pack "help\n")
+                         assertEqual "testSrun ret_srun" (AugRet 1) ret_srun
+                         
+                         hFlush fptr_Output
+                         hClose fptr_Output
+                         
+                         contents <- IO.readFile (cwd++"/HUnitAug.txt")
+                         assertEqual "check aug_srun_help" (Data.List.isInfixOf "Commands:" contents) True
+                         assertEqual "check aug_srun_help" (Data.List.isInfixOf "Type 'help <command>' for more information on a command" contents) True
+                         
+                         removeFile (cwd++"/HUnitAug.txt")
+
+                     )
+           
+testSrunQuit :: Test
+testSrunQuit = TestCase ( with_augptr $ \aug_ptr -> do                         
+                         
+                         cwd <- getCurrentDirectory
+                         fptr_Output <- openFile (cwd++"/HUnitAug.txt") WriteMode
+                         ret_srun <- aug_srun aug_ptr fptr_Output (Data.ByteString.Char8.pack "quit\n")
+                         assertEqual "testSrun ret_srun_quit" (AugRet (-2)) ret_srun
+                         
+                         hFlush fptr_Output
+                         hClose fptr_Output
+                         
+                         contents <- IO.readFile (cwd++"/HUnitAug.txt")
+                         assertEqual "check aug_srun_quit_contents" (contents == "") True
+                         
+                         -- removeFile (cwd++"/HUnitAug.txt")
+
+                     )
+#endif
+
 -- ---------------
 -- aug_error tests
 -- ---------------
@@ -580,6 +623,34 @@ testErrMessage = TestCase ( with_augptr $ \aug_ptr -> do
                             )
 #endif
 
+-- ----------------
+-- aug_to_xml tests
+-- ----------------
+#ifdef HAS_AUGEAS_TO_XML
+testToXml :: Test
+testToXml = TestCase ( with_augptr $ \aug_ptr -> do
+                          
+                          -- test success (ret==0, AugeasXmlNode != NULL)
+                          ret_toxml <- aug_to_xml aug_ptr (Data.ByteString.Char8.pack "/files/etc/hosts/1/canonical") [none] 
+                          assertEqual "testGoodToXml" success (fst ret_toxml)
+                          
+                          assertBool "testGoodToXmlJustPtr" ((snd ret_toxml) /= Nothing)
+                          
+                          ret_toxml2 <- aug_to_xml aug_ptr (Data.ByteString.Char8.pack "/files/etc/hosts/1/canonical") [save_backup] 
+                          assertEqual "testFlagsNotZero" System.Augeas.error (fst ret_toxml2)
+                          
+                          err_message <- aug_error_message aug_ptr
+                          assertEqual "testFlagsNotZeroErr" (Data.ByteString.Char8.pack "Invalid argument in function call") err_message
+                          
+                          err_details <- aug_error_details aug_ptr
+                          assertEqual "testFlagsNotZeroErrDetails" (Data.ByteString.Char8.pack "aug_to_xml: FLAGS must be 0") err_details
+
+                          assertEqual "testFlagsNotZeroNode" Nothing (snd ret_toxml2)
+                          
+                          )
+#endif
+
+
 
 
 
@@ -666,16 +737,23 @@ main = runTestTT $ TestList [
         ,testPrint
 #endif
 
+#ifdef HAS_AUGEAS_SRUN
+        ,testSrunHelp
+        ,testSrunQuit
+#endif
 
 #ifndef HAS_AUGEAS_ERROR
         ,testError
 #endif
+
 #ifdef HAS_AUGEAS_ERROR_MESSAGE
-        -- aug_error_minor_message
-        -- aug_error_details
         ,testErrMessage
 #endif
 
+#ifdef HAS_AUGEAS_TO_XML
+        ,testToXml
+#endif
+
         -- aug_close already handled in ForeignPtr, so there's no need to surface it to Haskell users at all.
 
        ]
\ No newline at end of file
