@@ -1,7 +1,7 @@
 -- file: System/Augeas.hs
 
 -- Haskell bindings for the Augeas library
--- Copyright (c) 2009-2011, Jude Nagurney
+-- Copyright (c) 2009-2012, Jude Nagurney
 
 -- This library is free software; you can redistribute it and/or modify it 
 -- under the terms of the GNU Lesser General Public License as published by 
@@ -54,6 +54,10 @@ module System.Augeas
 #ifdef HAS_AUGEAS_SPAN
     , err_no_span
 #endif
+#ifdef HAS_AUGEAS_SRUN
+    , err_mv_desc
+    , err_cmd_run
+#endif
                
     -- * Functions
     , aug_init
@@ -70,10 +74,14 @@ module System.Augeas
     , aug_save
     , aug_load
     , aug_print
+    , aug_srun
     , aug_error    
     , aug_error_message        
     , aug_error_minor_message
     , aug_error_details
+#ifdef HAS_AUGEAS_TO_XML
+    , aug_to_xml
+#endif
     ) where
 
 import System.IO
@@ -253,9 +261,9 @@ foreign import ccall safe "augeas.h aug_defvar"
   
    Define a variable NAME whose value is the result of evaluating EXPR. If
    a variable NAME already exists, its name will be replaced with the
-   result of evaluating EXPR.
+   result of evaluating EXPR.  Context will not be applied to EXPR.
   
-   If EXPR is Nothing, the variable NAME will be removed if it is defined.
+   If (Maybe EXPR) is Nothing, the variable NAME will be removed if it is defined.
   
    Path variables can be used in path expressions later on by prefixing
    them with '$'.
@@ -272,6 +280,7 @@ aug_defvar :: Ptr Augeas  -- ^ Augeas pointer
 aug_defvar aug_ptr bstr1 maybe_bstr2 = 
 #ifndef HAS_AUGEAS_DEFVAR
                Prelude.error "aug_defvar requires at least augeas version 0.5.0"
+               Prelude.error ((show aug_ptr) ++ (show bstr1) ++ (show maybe_bstr2))  -- stop compiler warning
 #else
                useAsCString bstr1 $ \name -> do
                  ret <- (case maybe_bstr2 of
@@ -322,6 +331,7 @@ aug_defnode :: Ptr Augeas  -- ^ Augeas pointer
 aug_defnode aug_ptr bstr1 bstr2 bstr3 = 
 #ifndef HAS_AUGEAS_DEFNODE
         Prelude.error "aug_defnode requires at least augeas version 0.5.0"
+        Prelude.error ((show aug_ptr) ++ (show bstr1) ++ (show bstr2) ++ (show bstr3))  -- stop compiler warning
 #else
         useAsCString bstr1 $ \name -> do
           useAsCString bstr2 $ \expr -> do
@@ -370,6 +380,7 @@ aug_get :: Ptr Augeas  -- ^ Augeas pointer
 aug_get aug_ptr bstr1 = 
 #ifndef HAS_AUGEAS_GET
     Prelude.error "aug_get requires at least augeas version 0.0.1"
+    Prelude.error ((show aug_ptr) ++ (show bstr1))  -- stop compiler warning
 #else
     useAsCString bstr1 $ \path -> do
       alloca $ \value -> do
@@ -420,6 +431,7 @@ aug_set :: Ptr Augeas  -- ^ Augeas pointer
 aug_set aug_ptr bs1 bs2 = 
 #ifndef HAS_AUGEAS_SET
     Prelude.error "aug_set requires at least augeas version 0.0.1"
+    Prelude.error ((show aug_ptr) ++ (show bs1) ++ (show bs2))  -- stop compiler warning
 #else
     useAsCString bs1 $ \path -> do
       useAsCString bs2 $ \value -> do
@@ -456,6 +468,7 @@ aug_setm :: Ptr Augeas          -- ^Augeas pointer
 aug_setm aug_ptr bstr1 maybe_bstr2 bstr3  =
 #ifndef HAS_AUGEAS_SETM
     Prelude.error "aug_setm requires at least augeas version 0.7.2"
+    Prelude.error ((show aug_ptr) ++ (show bstr1) ++ (show maybe_bstr2) ++ (show bstr3))  -- stop compiler warning
 #else
     useAsCString bstr1 $ \base -> do
       useAsCString bstr3 $ \value -> do
@@ -505,6 +518,7 @@ aug_span :: Ptr Augeas  -- ^ Augeas pointer
 aug_span aug_ptr bs1 =
 #ifndef HAS_AUGEAS_SPAN
     Prelude.error "aug_span requires at least augeas version 0.8.0"
+    Prelude.error ((show aug_ptr) ++ (show bs1))  -- stop compiler warning
 #else
     useAsCString bs1 $ \path -> do
       alloca $ \filename -> do
@@ -566,6 +580,7 @@ aug_insert :: Ptr Augeas   -- ^ Augeas pointer
 aug_insert aug_ptr bs1 bs2 before = 
 #ifndef HAS_AUGEAS_INSERT
     Prelude.error "aug_insert requires at least augeas version 0.0.1"
+    Prelude.error ((show aug_ptr) ++ (show bs1) ++ (show bs2) ++ (show before))  -- stop compiler warning    
 #else
     useAsCString bs1 $ \path -> do
       useAsCString bs2 $ \label -> do
@@ -595,6 +610,7 @@ aug_rm :: Ptr Augeas  -- ^ Augeas pointer
 aug_rm aug_ptr bs_path = 
 #ifndef HAS_AUGEAS_RM
     Prelude.error "aug_rm requires at least augeas version 0.0.1"
+    Prelude.error ((show aug_ptr) ++ (show bs_path))  -- stop compiler warning    
 #else
     useAsCString bs_path $ \path -> do    
       ret <- c_aug_rm aug_ptr path
@@ -632,6 +648,7 @@ aug_mv :: Ptr Augeas  -- ^ Augeas pointer
 aug_mv aug_ptr bs_src bs_dst = 
 #ifndef HAS_AUGEAS_MV
         Prelude.error "aug_mv requires at least augeas version 0.3.0"
+        Prelude.error ((show aug_ptr) ++ (show bs_src) ++ (show bs_dst))  -- stop compiler warning    
 #else
         useAsCString bs_src $ \src -> do
           useAsCString bs_dst $ \dst -> do
@@ -682,6 +699,7 @@ aug_match :: Ptr Augeas    -- ^ Augeas pointer
 aug_match aug_ptr bs_path = 
 #ifndef HAS_AUGEAS_MATCH
    Prelude.error "aug_match requires at least augeas version 0.0.1"  
+   Prelude.error ((show aug_ptr) ++ (show bs_path))  -- stop compiler warning    
 #else
     useAsCString bs_path $ \path -> do
       alloca $ \matches -> do
@@ -729,6 +747,7 @@ aug_save :: Ptr Augeas    -- ^ Augeas pointer
 aug_save aug_ptr = 
 #ifndef HAS_AUGEAS_SAVE
     Prelude.error "aug_save requires at least augeas version 0.0.1"
+    Prelude.error (show aug_ptr)  -- stop compiler warning    
 #else
     do 
       ret <- c_aug_save aug_ptr
@@ -780,6 +799,7 @@ aug_load :: Ptr Augeas    -- ^ Augeas pointer
 aug_load aug_ptr = 
 #ifndef HAS_AUGEAS_LOAD
     Prelude.error "aug_load requires at least augeas version 0.5.0"
+    Prelude.error (show aug_ptr)  -- stop compiler warning    
 #else
     do
       ret <- c_aug_load aug_ptr
@@ -827,6 +847,7 @@ aug_print :: Ptr Augeas  -- ^ Augeas pointer
 aug_print aug_ptr fptr_out bs_path = 
 #ifndef HAS_AUGEAS_PRINT
    Prelude.error "aug_print requires at least augeas version 0.0.1"
+   Prelude.error ((show aug_ptr) ++ (show fptr_out) ++ (show bs_path))  -- stop compiler warning    
 #else
    useAsCString bs_path $ \path -> do
      out <- handleToCFile fptr_out "w"
@@ -836,6 +857,90 @@ aug_print aug_ptr fptr_out bs_path =
      return(ret)
 #endif
 
+-- ----------
+-- aug_to_xml
+-- ----------
+#ifdef HAS_AUGEAS_TO_XML
+-- TODO:  What's the standard GHC interface to libxml2 ? : libxml  (Text.XML.LibXML) or  xml (Text.XML.Light)
+foreign import ccall safe "augeas.h aug_to_xml"
+  c_aug_to_xml :: Ptr Augeas            -- aug
+             -> CString                 -- path
+             -> (Ptr (Ptr AugeasXmlNode ))    -- xmldoc
+             -> AugFlag                 -- flags
+             -> IO (AugRet)             -- error code  (0 on success, <0 on error)
+#endif
+{-|
+   Function: aug_to_xml
+
+   Turn the Augeas tree(s) matching PATH into an XML tree XMLDOC. The
+   parameter FLAGS is currently unused and must be set to 0.
+
+   Returns:
+   0 on success, or a negative value on failure
+
+   In case of failure, *xmldoc is set to Nothing
+-}
+
+aug_to_xml :: Ptr Augeas           -- ^ Augeas pointer
+           -> ByteString           -- ^ path
+           -> [AugFlag]            -- ^ flags    
+           -> IO (AugRet, Maybe (Ptr AugeasXmlNode))  -- ^ error code
+aug_to_xml aug_ptr bs_path flags  =
+#ifndef HAS_AUGEAS_TO_XML
+  Prelude.error "aug_to_xml requires at least augeas version 0.10.0"
+  Prelude.error ((show aug_ptr) ++ (show bs_path) ++ (show flags))  -- stop compiler warning
+#else
+  useAsCString bs_path $ \path -> do
+    alloca $ \ptr -> do
+      ret <- c_aug_to_xml aug_ptr path ptr (combineFlags flags)
+      ret_xml <- peek ptr
+      if ret_xml == nullPtr 
+         then do 
+             return (ret, Nothing)
+         else do 
+             return (ret, (Just ret_xml))
+
+#endif
+
+-- --------
+-- aug_srun
+-- --------
+#ifdef HAS_AUGEAS_SRUN
+foreign import ccall safe "augeas.h aug_srun"
+  c_aug_srun :: Ptr Augeas                      -- aug
+             -> Ptr CFile                       -- out
+             -> CString                         -- text
+             -> IO (AugRet)                     -- error code
+#endif
+{-|
+  Function: aug_srun
+ 
+  Run one or more newline-separated commands. The output of the commands
+  will be printed to OUT. Running just 'help' will print what commands are
+  available. Commands accepted by this are identical to what augtool
+  accepts.
+ 
+  Returns:
+  the number of executed commands on success, -1 on failure, and -2 if a
+  'quit' command was encountered
+-}
+
+aug_srun :: Ptr Augeas  -- ^ Augeas pointer
+         -> Handle      -- ^ OUT Already opened file handle
+         -> ByteString  -- ^ TEXT
+         -> IO (AugRet) -- ^ return value
+aug_srun aug_ptr fptr_out bs_text =
+#ifndef HAS_AUGEAS_SRUN
+ Prelude.error "aug_srun requires at least augeas version 0.9.0"
+ Prelude.error ((show aug_ptr) ++ (show fptr_out) ++ (show bs_text))  -- stop compiler warning
+#else
+ useAsCString bs_text $ \text -> do
+   out <- handleToCFile fptr_out "w"
+   ret <- c_aug_srun aug_ptr out text
+   _ <- fflush out
+   _ <- fclose out
+   return(ret)
+#endif
 
 -- ---------
 -- aug_error
@@ -855,6 +960,7 @@ aug_error :: Ptr Augeas  -- ^ Augeas pointer
 aug_error aug_ptr = 
 #ifndef HAS_AUGEAS_ERROR
         Prelude.error "aug_error requires at least augeas version 0.6.0"
+        Prelude.error (show aug_ptr)  -- stop compiler warning    
 #else
         do 
           ret <- c_aug_error aug_ptr
@@ -878,6 +984,7 @@ aug_error_message :: Ptr Augeas  -- ^ Augeas pointer
 aug_error_message aug_ptr = 
 #ifndef HAS_AUGEAS_ERROR_MESSAGE
     Prelude.error "aug_error_message requires at least augeas version 0.6.0"
+    Prelude.error (show aug_ptr)  -- stop compiler warning        
 #else
     do
       cstr <- c_aug_error_message aug_ptr
@@ -904,6 +1011,7 @@ aug_error_minor_message :: Ptr Augeas      -- ^ Augeas pointer
 aug_error_minor_message aug_ptr = 
 #ifndef HAS_AUGEAS_ERROR_MINOR_MESSAGE
     Prelude.error "aug_error_minor_message requires at least augeas version 0.6.0"
+    Prelude.error (show aug_ptr)  -- stop compiler warning    
 #else
     do
       cstr <- c_aug_error_minor_message aug_ptr
@@ -930,6 +1038,7 @@ aug_error_details :: Ptr Augeas  -- ^ Augeas pointer
 aug_error_details aug_ptr = 
 #ifndef HAS_AUGEAS_ERROR_DETAILS
     Prelude.error "aug_error_details requires at least augeas version 0.6.0"
+    Prelude.error (show aug_ptr)  -- stop compiler warning    
 #else
     do 
       cstr <- c_aug_error_details aug_ptr
